@@ -1,15 +1,15 @@
 var TypeTraits_8h =
 [
-    [ "sdbus::request_slot_t", "structsdbus_1_1request__slot__t.html", null ],
+    [ "sdbus::return_slot_t", "structsdbus_1_1return__slot__t.html", null ],
     [ "sdbus::floating_slot_t", "structsdbus_1_1floating__slot__t.html", null ],
-    [ "sdbus::dont_request_slot_t", "structsdbus_1_1dont__request__slot__t.html", null ],
     [ "sdbus::adopt_message_t", "structsdbus_1_1adopt__message__t.html", null ],
     [ "sdbus::adopt_fd_t", "structsdbus_1_1adopt__fd__t.html", null ],
     [ "sdbus::dont_run_event_loop_thread_t", "structsdbus_1_1dont__run__event__loop__thread__t.html", null ],
     [ "sdbus::with_future_t", "structsdbus_1_1with__future__t.html", null ],
     [ "sdbus::dont_expect_reply_t", "structsdbus_1_1dont__expect__reply__t.html", null ],
-    [ "sdbus::signature_of< _T >", "structsdbus_1_1signature__of.html", null ],
+    [ "sdbus::signature_of< _T, _Enable >", "structsdbus_1_1signature__of.html", null ],
     [ "sdbus::signature_of< const _T >", "structsdbus_1_1signature__of_3_01const_01__T_01_4.html", null ],
+    [ "sdbus::signature_of< volatile _T >", "structsdbus_1_1signature__of_3_01volatile_01__T_01_4.html", null ],
     [ "sdbus::signature_of< _T & >", "structsdbus_1_1signature__of_3_01__T_01_6_01_4.html", null ],
     [ "sdbus::signature_of< void >", "structsdbus_1_1signature__of_3_01void_01_4.html", null ],
     [ "sdbus::signature_of< bool >", "structsdbus_1_1signature__of_3_01bool_01_4.html", null ],
@@ -21,27 +21,35 @@ var TypeTraits_8h =
     [ "sdbus::signature_of< int64_t >", "structsdbus_1_1signature__of_3_01int64__t_01_4.html", null ],
     [ "sdbus::signature_of< uint64_t >", "structsdbus_1_1signature__of_3_01uint64__t_01_4.html", null ],
     [ "sdbus::signature_of< double >", "structsdbus_1_1signature__of_3_01double_01_4.html", null ],
+    [ "sdbus::signature_of< std::string >", "structsdbus_1_1signature__of_3_01std_1_1string_01_4.html", null ],
+    [ "sdbus::signature_of< std::string_view >", "structsdbus_1_1signature__of_3_01std_1_1string__view_01_4.html", null ],
     [ "sdbus::signature_of< char * >", "structsdbus_1_1signature__of_3_01char_01_5_01_4.html", null ],
     [ "sdbus::signature_of< const char * >", "structsdbus_1_1signature__of_3_01const_01char_01_5_01_4.html", null ],
     [ "sdbus::signature_of< char[_N]>", "structsdbus_1_1signature__of_3_01char_0f__N_0e_4.html", null ],
     [ "sdbus::signature_of< const char[_N]>", "structsdbus_1_1signature__of_3_01const_01char_0f__N_0e_4.html", null ],
-    [ "sdbus::signature_of< std::string >", "structsdbus_1_1signature__of_3_01std_1_1string_01_4.html", null ],
+    [ "sdbus::signature_of< BusName >", "structsdbus_1_1signature__of_3_01BusName_01_4.html", null ],
+    [ "sdbus::signature_of< InterfaceName >", "structsdbus_1_1signature__of_3_01InterfaceName_01_4.html", null ],
+    [ "sdbus::signature_of< MemberName >", "structsdbus_1_1signature__of_3_01MemberName_01_4.html", null ],
     [ "sdbus::signature_of< Struct< _ValueTypes... > >", "structsdbus_1_1signature__of_3_01Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
     [ "sdbus::signature_of< Variant >", "structsdbus_1_1signature__of_3_01Variant_01_4.html", null ],
+    [ "sdbus::signature_of< std::variant< Elements... > >", "structsdbus_1_1signature__of_3_01std_1_1variant_3_01Elements_8_8_8_01_4_01_4.html", null ],
     [ "sdbus::signature_of< ObjectPath >", "structsdbus_1_1signature__of_3_01ObjectPath_01_4.html", null ],
     [ "sdbus::signature_of< Signature >", "structsdbus_1_1signature__of_3_01Signature_01_4.html", null ],
     [ "sdbus::signature_of< UnixFd >", "structsdbus_1_1signature__of_3_01UnixFd_01_4.html", null ],
+    [ "sdbus::signature_of< DictEntry< _T1, _T2 > >", "structsdbus_1_1signature__of_3_01DictEntry_3_01__T1_00_01__T2_01_4_01_4.html", null ],
     [ "sdbus::signature_of< std::vector< _Element, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1vector_3_01__Element_00_01__Allocator_01_4_01_4.html", null ],
     [ "sdbus::signature_of< std::array< _Element, _Size > >", "structsdbus_1_1signature__of_3_01std_1_1array_3_01__Element_00_01__Size_01_4_01_4.html", null ],
+    [ "sdbus::signature_of< _Enum, typename std::enable_if_t< std::is_enum_v< _Enum > > >", "structsdbus_1_1signature__of_3_01__Enum_00_01typename_01std_1_1enable__if__t_3_01std_1_1is__enum__v_3_01__Enum_01_4_01_4_01_4.html", null ],
     [ "sdbus::signature_of< std::map< _Key, _Value, _Compare, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1map_3_01__Key_00_01__Value_00_01__Compare_00_01__Allocator_01_4_01_4.html", null ],
     [ "sdbus::signature_of< std::unordered_map< _Key, _Value, _Hash, _KeyEqual, _Allocator > >", "structsdbus_1_1signature__of_3_01std_1_1unordered__map_3_01__Key_00_01__Value_00_01__Hash_00_01_40048d72e250466c6428c038be9a5369.html", null ],
+    [ "sdbus::signature_of< std::tuple< _Types... > >", "structsdbus_1_1signature__of_3_01std_1_1tuple_3_01__Types_8_8_8_01_4_01_4.html", null ],
     [ "sdbus::function_traits< _Type >", "structsdbus_1_1function__traits.html", null ],
     [ "sdbus::function_traits< const _Type >", "structsdbus_1_1function__traits_3_01const_01__Type_01_4.html", null ],
     [ "sdbus::function_traits< _Type & >", "structsdbus_1_1function__traits_3_01__Type_01_6_01_4.html", null ],
     [ "sdbus::function_traits_base< _ReturnType, _Args >", "structsdbus_1_1function__traits__base.html", "structsdbus_1_1function__traits__base" ],
     [ "sdbus::function_traits_base< _ReturnType, _Args >::arg< _Idx >", "structsdbus_1_1function__traits__base_1_1arg.html", null ],
     [ "sdbus::function_traits< _ReturnType(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07__Args_8_8_8_08_4.html", null ],
-    [ "sdbus::function_traits< void(const Error *, _Args...)>", "structsdbus_1_1function__traits_3_01void_07const_01Error_01_5_00_01__Args_8_8_8_08_4.html", null ],
+    [ "sdbus::function_traits< void(std::optional< Error >, _Args...)>", "structsdbus_1_1function__traits_3_01void_07std_1_1optional_3_01Error_01_4_00_01__Args_8_8_8_08_4.html", null ],
     [ "sdbus::function_traits< void(Result< _Results... >, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_00_01__Args_8_8_8_08_4.html", null ],
     [ "sdbus::function_traits< void(Result< _Results... > &&, _Args...)>", "structsdbus_1_1function__traits_3_01void_07Result_3_01__Results_8_8_8_01_4_01_6_6_00_01__Args_8_8_8_08_4.html", null ],
     [ "sdbus::function_traits< _ReturnType(*)(_Args...)>", "structsdbus_1_1function__traits_3_01__ReturnType_07_5_08_07__Args_8_8_8_08_4.html", null ],
@@ -52,8 +60,6 @@ var TypeTraits_8h =
     [ "sdbus::function_traits< std::function< FunctionType > >", "structsdbus_1_1function__traits_3_01std_1_1function_3_01FunctionType_01_4_01_4.html", null ],
     [ "sdbus::tuple_of_function_input_arg_types< _Function >", "structsdbus_1_1tuple__of__function__input__arg__types.html", null ],
     [ "sdbus::tuple_of_function_output_arg_types< _Function >", "structsdbus_1_1tuple__of__function__output__arg__types.html", null ],
-    [ "sdbus::aggregate_signature< _Type >", "structsdbus_1_1aggregate__signature.html", null ],
-    [ "sdbus::aggregate_signature< std::tuple< _Types... > >", "structsdbus_1_1aggregate__signature_3_01std_1_1tuple_3_01__Types_8_8_8_01_4_01_4.html", null ],
     [ "sdbus::signature_of_function_input_arguments< _Function >", "structsdbus_1_1signature__of__function__input__arguments.html", null ],
     [ "sdbus::signature_of_function_output_arguments< _Function >", "structsdbus_1_1signature__of__function__output__arguments.html", null ],
     [ "sdbus::future_return< _Args >", "structsdbus_1_1future__return.html", null ],
