@@ -3,8 +3,12 @@ var Types_8h =
     [ "sdbus::Variant", "classsdbus_1_1Variant.html", null ],
     [ "sdbus::Struct< _ValueTypes >", "classsdbus_1_1Struct.html", null ],
     [ "sdbus::ObjectPath", "classsdbus_1_1ObjectPath.html", null ],
+    [ "sdbus::BusName", "classsdbus_1_1BusName.html", null ],
+    [ "sdbus::InterfaceName", "classsdbus_1_1InterfaceName.html", null ],
+    [ "sdbus::MemberName", "classsdbus_1_1MemberName.html", null ],
     [ "sdbus::Signature", "classsdbus_1_1Signature.html", null ],
     [ "sdbus::UnixFd", "classsdbus_1_1UnixFd.html", null ],
     [ "std::tuple_element< _I, sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__element_3_01__I_00_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
-    [ "std::tuple_size< sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__size_3_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ]
+    [ "std::tuple_size< sdbus::Struct< _ValueTypes... > >", "structstd_1_1tuple__size_3_01sdbus_1_1Struct_3_01__ValueTypes_8_8_8_01_4_01_4.html", null ],
+    [ "DictEntry", "Types_8h.html#a7081ae84d5ccb9083d7aac74e1064370", null ]
 ];
\ No newline at end of file
