@@ -14,5 +14,7 @@ var dir_0f5f5ecbc08a2bb89a9a77b287d7bdcf =
     [ "sdbus-c++.h", "sdbus-c_09_09_8h.html", null ],
     [ "StandardInterfaces.h", "StandardInterfaces_8h.html", "StandardInterfaces_8h" ],
     [ "Types.h", "Types_8h.html", "Types_8h" ],
-    [ "TypeTraits.h", "TypeTraits_8h.html", "TypeTraits_8h" ]
+    [ "TypeTraits.h", "TypeTraits_8h.html", "TypeTraits_8h" ],
+    [ "VTableItems.h", "VTableItems_8h.html", "VTableItems_8h" ],
+    [ "VTableItems.inl", "VTableItems_8inl.html", null ]
 ];
\ No newline at end of file
