@@ -1,11 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "acdefghilmoprstuvw",
-  1: "adefimoprstuvw",
-  2: "acefimpst",
-  3: "acefghilmprsu",
+  0: "abcdefgilmnoprstuvw",
+  1: "abdefimnoprstuvw",
+  2: "acefimpstv",
+  3: "acdegilprsu",
   4: "eft",
-  5: "cdlsu"
+  5: "d",
+  6: "clsu"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "files",
   3: "functions",
   4: "variables",
-  5: "pages"
+  5: "typedefs",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Files",
   3: "Functions",
   4: "Variables",
-  5: "Pages"
+  5: "Typedefs",
+  6: "Pages"
 };
 
